package ru.myitschool.work.ui.main

import android.os.Bundle
import android.view.View
import android.widget.Toast
import androidx.fragment.app.Fragment
import androidx.fragment.app.setFragmentResultListener
import androidx.lifecycle.lifecycleScope
import androidx.navigation.fragment.findNavController
import kotlinx.coroutines.launch
import ru.myitschool.work.R
import ru.myitschool.work.api.ApiService
import ru.myitschool.work.api.EmployeeData
import ru.myitschool.work.core.Constants
import ru.myitschool.work.databinding.FragmentMainBinding
import ru.myitschool.work.SessionManager
import retrofit2.Retrofit
import retrofit2.converter.gson.GsonConverterFactory
import ru.myitschool.work.ui.qr.scan.QrScanDestination

class MainFragment : Fragment(R.layout.fragment_main) {
    private var _binding: FragmentMainBinding? = null
    private val binding get() = _binding!!

    private lateinit var apiService: ApiService

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        apiService = Retrofit.Builder()
            .baseUrl(Constants.SERVER_ADDRESS)
            .addConverterFactory(GsonConverterFactory.create())
            .build()
            .create(ApiService::class.java)
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)
        _binding = FragmentMainBinding.bind(view)

        setupUI()
        fetchUserInfo()

        // Проверяем, есть ли результат QR
        checkQrResult()
    }

    private fun checkQrResult() {
        // Слушаем результат QR сканирования
        setFragmentResultListener(QrScanDestination.REQUEST_KEY) { _, bundle ->
            val qrData = QrScanDestination.getDataIfExist(bundle)
            if (qrData != null) {
                // Если данные QR есть, переходим на экран с результатом
                val resultBundle = QrScanDestination.packToBundle(qrData)
                findNavController().navigate(R.id.qrResultFragment, resultBundle)
            } else {
                Toast.makeText(requireContext(), "QR данные не найдены", Toast.LENGTH_SHORT).show()
            }
        }
    }

    private fun setupUI() {
        binding.refresh.setOnClickListener {
            fetchUserInfo()
        }

        binding.scanQrCode?.setOnClickListener {
            // Переход к экрану сканирования QR-кода
            findNavController().navigate(R.id.qrScanFragment) // Убедитесь, что у вас есть правильный ID для навигации
        }

        // Проверяем роль пользователя и показываем кнопку AdminPanel, если роль admin
        if (SessionManager.userRole == "admin") {
            binding.adminPanelButton?.visibility = View.VISIBLE
            binding.adminPanelButton?.setOnClickListener {
                findNavController().navigate(R.id.adminFragment) // Переход к экрану администратора
            }
        } else {
            binding.adminPanelButton?.visibility = View.GONE // Скрываем кнопку, если не admin
        }
    }

    private fun fetchUserInfo() {
        lifecycleScope.launch {
            val login = SessionManager.userLogin ?: run {
                binding.error.text = "Пользователь не авторизован"
                binding.error.visibility = View.VISIBLE
                return@launch
            }
            val authHeader = SessionManager.getAuthHeader() ?: run {
                binding.error.text = "Ошибка авторизации"
                binding.error.visibility = View.VISIBLE
                return@launch
            }

            try {
                val response = apiService.getUserInfo(login, authHeader)

                // Логируем код ответа
                Log.d("MainFragment", "Response code: ${response.code()}")

                if (response.isSuccessful) {
                    val employeeData = response.body()
                    employeeData?.let {
                        binding.fullname.text = it.name
                        binding.position.text = it.position
                        binding.lastEntry.text = it.lastVisit

                        // Логируем URL аватара
                        Log.d("MainFragment", "Avatar URL: ${it.avatarUrl}")

                        // Загрузка аватара с помощью Picasso
                        if (it.avatarUrl != null) {
                            Picasso.get()
                                .load(it.avatarUrl)
                                .placeholder(R.drawable.ic_refresh) // Замените на ваш ресурс-заполнитель
                                .error(R.drawable.ic_close) // Замените на ваш ресурс ошибки
                                .into(binding.photo)
                            binding.photo.visibility = View.VISIBLE
                        } else {
                            binding.photo.visibility = View.GONE // Скрыть, если URL нет
                        }

                        // Показываем кнопку "Сканировать QR-код" после успешного получения данных
                        binding.scanQrCode?.visibility = View.VISIBLE
                    }
                } else {
                    binding.error.text = "Ошибка получения данных: ${response.message()}"
                    binding.error.visibility = View.VISIBLE
                }
            } catch (e: Exception) {
                Log.e("MainFragment", "Error fetching user info", e)
                binding.error.text = "Ошибка сети: ${e.message}"
                binding.error.visibility = View.VISIBLE
            }
        }
    }

    private fun checkQrResult() {
        // Слушаем результат QR сканирования
        setFragmentResultListener(QrScanDestination.REQUEST_KEY) { _, bundle ->
            val qrData = QrScanDestination.getDataIfExist(bundle)
            if (qrData != null) {
                // Если данные QR есть, переходим на экран с результатом
                val resultBundle = QrScanDestination.packToBundle(qrData)
                findNavController().navigate(R.id.qrResultFragment, resultBundle)
            } else {
                Toast.makeText(requireContext(), "QR данные не найдены", Toast.LENGTH_SHORT).show()
            }
        }
    }

    override fun onDestroyView() {
        _binding = null
        super.onDestroyView()
    }
}